@@ -5,7 +5,7 @@ LabExT  Copyright (C) 2021  ETH Zurich and Polariton Technologies AG
 This program is free software and comes with ABSOLUTELY NO WARRANTY; for details see LICENSE file.
 """
 
-from LabExT.Measurements.MeasAPI import MeasParamInt
+from LabExT.Measurements.MeasAPI import MeasParamInt, MeasParamFloat
 
 from LabExT.ViewModel.Utilities.ObservableList import ObservableList
 
@@ -26,7 +26,8 @@ class LiveViewerModel:
         # these are the general settings
         self.general_settings = {
             # number of points kept
-            'number of points kept': MeasParamInt(value=100)
+            'number of points kept': MeasParamInt(value=100),
+            'minimum y-axis span': MeasParamFloat(value=4.0),
         }
 
         # the plot collection, which is used for the plotting frame
@@ -47,3 +48,6 @@ class LiveViewerModel:
 
         # the number of points kept
         self.plot_size = 100
+
+        # the minimum y span
+        self.min_y_span = 4.0
